macro_rules! flush {
() => { ... };
}Expand description
Allows flushing onto an implementor of Flush, which can be modified with
with_flush! macro and unwraps and ignores errors from try_flush
macro_rules! flush {
() => { ... };
}Allows flushing onto an implementor of Flush, which can be modified with
with_flush! macro and unwraps and ignores errors from try_flush